@@ -47,7 +47,7 @@
 #include <asm/uaccess.h>
 #include <asm/io.h>
 
-#define TP_VERSION "0.44"
+#define TP_VERSION "0.45"
 #define TP_DESC "ThinkPad SMAPI Support"
 #define TP_DIR "smapi"
 
@@ -201,7 +201,7 @@ static int smapi_request(u32 inEBX, u32 inECX,
 			 "=m"(tmpEDI),
 			 "=m"(tmpESI)
 			:"m"(inEBX), "m"(inECX), "m"(inEDI), "m"(inESI),
-			 "m"((u16)smapi_port)
+			 "m"(smapi_port)
 			:"%eax", "%ebx", "%ecx", "%edx", "%edi",
 			 "%esi");
 
